==> graphmonkey_1.5.orig.tar.gz: GraphMonkey-1.5-src/About_Form.cs <==
/*
* 21/08/2004 - 19:29
*
* GraphMonkey - mono based graphing calculator
* Copyright (C) 2004 Bellabes Lounis
* nolius@users.sourceforge.net
*
* This program is free software; you can redistribute it and/or
* modify it under the terms of the GNU General Public License
* as published by the Free Software Foundation; either version 2
* of the License, or any later version.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with this program; if not, write to the Free Software
* Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*/

using System;
using Gtk;
using GtkSharp;


public class About_Form : Window
{
	public About_Form () : base ("Help")
	{
		this.SetDefaultSize (100, 300);
		this.Resizable = false;
		
		Table tableLayout = new Table(1, 3, false);

		//GraphMonkey
		Label label_monkey = new Label("GraphMonkey 1.5");
		tableLayout.Attach(label_monkey, 0, 1, 0, 1);
		
		//blank
		Label label_blank = new Label("");
		tableLayout.Attach(label_blank, 0, 1, 1, 2);
		
		//name
		Label label_name = new Label("     By Lounis Bellabes     ");
		tableLayout.Attach(label_name, 0, 1, 2, 3);
		
		//email
		Label label_email = new Label(" nolius@users.sourceforge.net ");
		tableLayout.Attach(label_email, 0, 1, 3, 4);

		//GPL
		Label label_gpl = new Label("GPL license");
		tableLayout.Attach(label_gpl, 0, 1, 4, 5);
		
		//blank2
		Label label_blank2 = new Label("-----------------------------");
		tableLayout.Attach(label_blank2, 0, 1, 5, 6);		
		
		//squareroots
		Label label_squareroots = new Label("square roots : sqrt()");
		tableLayout.Attach(label_squareroots, 0, 1, 7, 8);
		
		//powers square
		Label label_powerssquare  = new Label("powers square : ^");
		tableLayout.Attach(label_powerssquare , 0, 1, 8, 9);		

		//sine
		Label label_sine = new Label("sine : sin()");
		tableLayout.Attach(label_sine, 0, 1, 9, 10);

		//cosine
		Label label_cosine = new Label("cosine : cos()");
		tableLayout.Attach(label_cosine, 0, 1, 10, 11);
	
		//tangent
		Label label_tangent = new Label("tangent : tan()");
		tableLayout.Attach(label_tangent, 0, 1, 11, 12);
		
		//arcsine
		Label label_arcsine = new Label("arcsine : asin()");
		tableLayout.Attach(label_arcsine, 0, 1, 12, 13);

		//arccosine
		Label label_arccosine = new Label("arccosine : acos()");
		tableLayout.Attach(label_arccosine, 0, 1, 13, 14);
		
		//arctangent
		Label label_arctangent = new Label("arctangent : atan()");
		tableLayout.Attach(label_arctangent, 0, 1, 14, 15);

		//hyperbolic sine : sinh()
		Label label_hyperbolicsine = new Label("hyperbolic sine : sinh()");
		tableLayout.Attach(label_hyperbolicsine, 0, 1, 15, 16);		

		//hyperbolic cosine : cosh()
		Label label_hyperboliccosine = new Label("hyperbolic cosine : cosh()");
		tableLayout.Attach(label_hyperboliccosine, 0, 1, 16, 17);
		
		//hyperbolic tangent
		Label label_hyperbolictangent = new Label("hyperbolic tangent : tan()");
		tableLayout.Attach(label_hyperbolictangent, 0, 1, 17, 18);
		
		//logarithm
		Label label_logarithm = new Label("logarithm : log()");
		tableLayout.Attach(label_logarithm, 0, 1, 18, 19);
		
		//exponential
		Label label_exponential = new Label("exponential : exp()");
		tableLayout.Attach(label_exponential, 0, 1, 19, 20);
		
		//blank3
		Label label_blank3 = new Label("");
		tableLayout.Attach(label_blank3, 0, 1, 20, 21);		
																																																												
		
		tableLayout.ShowAll();
		this.Add (tableLayout);
        
		this.ShowAll ();
		
		
	}
}

==> graphmonkey_1.6.orig.tar.gz: GraphMonkey-1.6-src/About_Form.cs <==
/*
* 21/08/2004 - 19:29
*
* GraphMonkey - mono based graphing calculator
* Copyright (C) 2004 Bellabes Lounis
* nolius@users.sourceforge.net
*
* This program is free software; you can redistribute it and/or
* modify it under the terms of the GNU General Public License
* as published by the Free Software Foundation; either version 2
* of the License, or any later version.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with this program; if not, write to the Free Software
* Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*/

using System;
using Gtk;
using GtkSharp;


public class About_Form : Window
{
	public About_Form () : base ("Help")
	{
		this.SetDefaultSize (100, 300);
		this.Resizable = false;
		
		Table tableLayout = new Table(1, 3, false);


		//blank
		Label label_blank4 = new Label("");
		tableLayout.Attach(label_blank4, 0, 1, 0, 1);
		
		//GraphMonkey
		Label label_monkey = new Label("GraphMonkey 1.6");
		tableLayout.Attach(label_monkey, 0, 1, 1, 2);
		
		//blank
		Label label_blank = new Label("");
		tableLayout.Attach(label_blank, 0, 1, 2, 3);
		
		//name
		Label label_name = new Label("     By Lounis Bellabes     ");
		tableLayout.Attach(label_name, 0, 1, 3, 4);
		
		//email
		Label label_email = new Label("   nolius@users.sourceforge.net   ");
		tableLayout.Attach(label_email, 0, 1, 4, 5);

		//GPL
		Label label_gpl = new Label("GPL license");
		tableLayout.Attach(label_gpl, 0, 1, 5, 6);
		
		//blank2
		Label label_blank2 = new Label("-----------------------------");
		tableLayout.Attach(label_blank2, 0, 1, 6, 7);		
		
		//squareroots
		Label label_squareroots = new Label("square roots : sqrt()");
		tableLayout.Attach(label_squareroots, 0, 1, 8, 9);
		
		//powers square
		Label label_powerssquare  = new Label("powers square : ^");
		tableLayout.Attach(label_powerssquare , 0, 1, 9, 10);		

		//sine
		Label label_sine = new Label("sine : sin()");
		tableLayout.Attach(label_sine, 0, 1, 10, 11);

		//cosine
		Label label_cosine = new Label("cosine : cos()");
		tableLayout.Attach(label_cosine, 0, 1, 11, 12);
	
		//tangent
		Label label_tangent = new Label("tangent : tan()");
		tableLayout.Attach(label_tangent, 0, 1, 12, 13);
		
		//arcsine
		Label label_arcsine = new Label("arcsine : asin()");
		tableLayout.Attach(label_arcsine, 0, 1, 13, 14);

		//arccosine
		Label label_arccosine = new Label("arccosine : acos()");
		tableLayout.Attach(label_arccosine, 0, 1, 14, 15);
		
		//arctangent
		Label label_arctangent = new Label("arctangent : atan()");
		tableLayout.Attach(label_arctangent, 0, 1, 15, 16);

		//hyperbolic sine : sinh()
		Label label_hyperbolicsine = new Label("hyperbolic sine : sinh()");
		tableLayout.Attach(label_hyperbolicsine, 0, 1, 16, 17);		

		//hyperbolic cosine : cosh()
		Label label_hyperboliccosine = new Label("hyperbolic cosine : cosh()");
		tableLayout.Attach(label_hyperboliccosine, 0, 1, 17, 18);
		
		//hyperbolic tangent
		Label label_hyperbolictangent = new Label("hyperbolic tangent : tanh()");
		tableLayout.Attach(label_hyperbolictangent, 0, 1, 18, 19);
		
		//logarithm
		Label label_logarithm = new Label("logarithm : log()");
		tableLayout.Attach(label_logarithm, 0, 1, 19, 20);
		
		//exponential
		Label label_exponential = new Label("exponential : exp()");
		tableLayout.Attach(label_exponential, 0, 1, 20, 21);
		
		//blank3
		Label label_blank3 = new Label("");
		tableLayout.Attach(label_blank3, 0, 1, 21, 22);		
																																																												
		
		tableLayout.ShowAll();
		this.Add (tableLayout);
        
		this.ShowAll ();
		
		
	}
}
